import { ValidationError } from 'class-validator';
import { eCheckResult, eLCID, eVisualFieldType } from '../../../../consts';
import { AllowPrimitives } from '../../../../types';
import { iRTextDataSource, RTextDataSource } from './text-data-source.model';
import { iRTextDataComparison, RTextDataComparison } from './text-data-comparison.model';
/**
* Text data field with values by source
*/
export interface iRTextData {
    /**
    * Type of the text data field
    * @type {eVisualFieldType}
    */
    type: eVisualFieldType;
    /**
    * Value of the text data field
    */
    value: string;
    /**
    * Overall check result of the text data field
    * @type {eCheckResult}
    */
    checkResult: eCheckResult;
    /**
    * LCID of the text data field
    * @type {eLCID}
    */
    lcid: eLCID;
    /**
    * Values of the text data field by source
    * @type {iRTextDataSource[]}
    */
    bySource: iRTextDataSource[];
    /**
    * Comparison results list
    * @type {iRTextDataComparison[]}
    */
    comparisonList: iRTextDataComparison[];
}
/**
* Text data field with values by source
*/
export declare class RTextData implements iRTextData {
    /**
    * Type of the text data field
    * @type {eVisualFieldType}
    */
    type: eVisualFieldType;
    /**
    * Value of the text data field
    */
    value: string;
    /**
    * Overall check result of the text data field
    * @type {eCheckResult}
    */
    checkResult: eCheckResult;
    /**
    * LCID of the text data field
    * @type {eLCID}
    */
    lcid: eLCID;
    /**
    * Comparison results list
    * @type {RTextDataComparison[]}
    */
    comparisonList: RTextDataComparison[];
    /**
    * Values of the text data field by source
    * @type {iRTextDataSource[]}
    */
    bySource: RTextDataSource[];
    /**
    * Create instance of RTextData from plain object
    * @param {AllowPrimitives<iRTextData>} input
    * @return {RTextData}
    */
    static fromPlain: (input: AllowPrimitives<iRTextData>) => RTextData;
    /**
    * Get validation errors
    * @param {RTextData} input
    * @return {ValidationError[]}
    */
    static getValidationErrors: (input: RTextData) => ValidationError[];
    /**
    * Check if input is valid
    * @param {RTextData | RTextData[]} input - Array of RTextData or single RTextData
    * @return {boolean}
    */
    static isValid: (input: RTextData | RTextData[]) => boolean;
}
